@@ -6,6 +6,7 @@ Can be also used to develop future code.
 
 
 """
+
 from nodes_and_edges import get_nodes_and_edges
 from os.path import join
 from json_to_csv import read_csv
@@ -14,11 +15,14 @@ from eurlex_scraping import *
 from cellar import *
 from sparql import *
 
+
+
+
 if __name__ == '__main__':
-    username = "n00ac9w5"
-    password = "XUtjyPDrl1c"
-    base_query = "SELECT DN,CI WHERE DN = %s"
-    input = " OR ".join(['62004CJ0292'])
-    query = base_query % (str(input))
-    response = run_eurlex_webservice_query(query, username, password)
-    b=2
\ No newline at end of file
+   celex = "62004CJ0292"
+   site = get_entire_page(celex)
+   text = get_full_text_from_html(site)
+   cits = get_citations_with_extra_info(text)
+   print(cits)
+   data = get_cellar_extra(sd='2023-01-01',max_ecli=100,save_file='n')
+   b=2
\ No newline at end of file
